@@ -7,8 +7,7 @@ from captcha.fields import CaptchaField
 
 
 TEST_TEMPLATE = r"""
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+<!doctype html>
 <html>
     <head>
         <meta http-equiv="Content-type" content="text/html; charset=utf-8">
@@ -95,20 +94,6 @@ def test_custom_error_message(request):
     return _test(request, CaptchaTestErrorMessageForm)
 
 
-def test_per_form_format(request):
-    class CaptchaTestFormatForm(forms.Form):
-        captcha = CaptchaField(
-            help_text="asdasd",
-            error_messages=dict(invalid="TEST CUSTOM ERROR MESSAGE"),
-            output_format=(
-                "%(image)s testPerFieldCustomFormatString "
-                "%(hidden_field)s %(text_field)s"
-            ),
-        )
-
-    return _test(request, CaptchaTestFormatForm)
-
-
 def test_non_required(request):
     class CaptchaTestForm(forms.Form):
         sender = forms.EmailField()
