@@ -1,6 +1,7 @@
 import json
 import os
 import random
+import secrets
 import subprocess
 import tempfile
 from io import BytesIO
@@ -80,8 +81,11 @@ def captcha_image(request, key, scale=1):
             charlist[-1] += char
         else:
             charlist.append(char)
-    for char in charlist:
-        fgimage = Image.new("RGB", size, settings.CAPTCHA_FOREGROUND_COLOR)
+
+    for index, char in enumerate(charlist):
+        fgimage = Image.new(
+            "RGB", size, settings.get_letter_color(index, "".join(charlist))
+        )
         charimage = Image.new("L", getsize(font, " %s " % char), "#000000")
         chardraw = ImageDraw.Draw(charimage)
         chardraw.text((0, 0), " %s " % char, font=font, fill="#ffffff")
@@ -158,20 +162,37 @@ def captcha_audio(request, key):
             text = text.replace("*", "times").replace("-", "minus").replace("+", "plus")
         else:
             text = ", ".join(list(text))
-        path = str(os.path.join(tempfile.gettempdir(), "%s.wav" % key))
-        subprocess.call([settings.CAPTCHA_FLITE_PATH, "-t", text, "-o", path])
+        path = str(
+            os.path.join(tempfile.gettempdir(), f"{key}_{secrets.token_urlsafe(6)}.wav")
+        )
+        subprocess.run([settings.CAPTCHA_FLITE_PATH, "-t", text, "-o", path])
 
         # Add arbitrary noise if sox is installed
         if settings.CAPTCHA_SOX_PATH:
+            try:
+                sample_rate = (
+                    subprocess.run(
+                        [settings.CAPTCHA_SOX_PATH, "--i", "-r", path],
+                        capture_output=True,
+                    )
+                    .stdout.decode()
+                    .strip()
+                )
+
+            except Exception:
+                sample_rate = "8000"
+
             arbnoisepath = str(
-                os.path.join(tempfile.gettempdir(), "%s_arbitrary.wav") % key
+                os.path.join(
+                    tempfile.gettempdir(),
+                    f"{key}_{secrets.token_urlsafe(6)}_noise.wav",
+                )
             )
-            mergedpath = str(os.path.join(tempfile.gettempdir(), "%s_merged.wav") % key)
-            subprocess.call(
+            subprocess.run(
                 [
                     settings.CAPTCHA_SOX_PATH,
                     "-r",
-                    "8000",
+                    sample_rate,
                     "-n",
                     arbnoisepath,
                     "synth",
@@ -181,7 +202,13 @@ def captcha_audio(request, key):
                     "-15",
                 ]
             )
-            subprocess.call(
+            mergedpath = str(
+                os.path.join(
+                    tempfile.gettempdir(),
+                    f"{key}_{secrets.token_urlsafe(6)}_merged.wav",
+                )
+            )
+            subprocess.run(
                 [
                     settings.CAPTCHA_SOX_PATH,
                     "-m",
@@ -199,8 +226,15 @@ def captcha_audio(request, key):
             os.rename(mergedpath, path)
 
         if os.path.isfile(path):
+            # Move the response file to a filelike that will be deleted on close
+            temporary_file = tempfile.TemporaryFile()
+            with open(path, "rb") as original_file:
+                temporary_file.write(original_file.read())
+            temporary_file.seek(0)
+            os.remove(path)
+
             response = RangedFileResponse(
-                request, open(path, "rb"), content_type="audio/wav"
+                request, temporary_file, content_type="audio/wav"
             )
             response["Content-Disposition"] = 'attachment; filename="{}.wav"'.format(
                 key
